@@ -7,5 +7,5 @@
 #' @export
 taxrank <- function() {
   c("kingdom", "phylum", "class", "order", "family", "genus", "species",
-    "infraspecific")
+    "subspecies", "infraspecific")
 }
