@@ -127,7 +127,7 @@ clean_data <- function(x){
 # param: fields (character) Default ("minimal") will return just taxon name,
 #    key, decimalLatitude, and decimalLongitute. "all" returns all fields. Or
 #    specify each field you want returned by name, e.g. fields =
-#    c('name',"decimalLatitude",'altitude').
+#    c('name','decimalLatitude','altitude').
 gbifparser_verbatim <- function(input, fields="minimal") {
   parse <- function(x) {
     nn <- vapply(names(x), function(z) {
@@ -306,7 +306,7 @@ nameusageparser <- function(z){
   })
   # reduce multiple element slots to comma sep
   if ("issues" %in% names(tmp)) {
-    tmp[names(tmp) %in% "issues"] <- collapse_name_issues(tmp)
+    tmp[names(tmp) %in% "issues"] <- collapse_issues(tmp)
   }
   df <- tibble::as_tibble(tmp)
   if (all(tomove %in% names(df))) {
@@ -541,7 +541,7 @@ check_for_a_pkg <- function(x) {
   }
 }
 
-assert <- function (x, y) {
+assert <- function(x, y) {
   if (!is.null(x)) {
     if (!inherits(x, y)) {
       stop(deparse(substitute(x)), " must be of class ",
@@ -550,6 +550,137 @@ assert <- function (x, y) {
   }
 }
 
+# check correctness issues and their type (type: "name" or "code")
+check_issues  <- function(type , ...) {
+  types <- c("occurrence", "name")
+  if (!length(dots(...)) == 0) {
+    filters <- parse_input(...)
+    iss <- c(filters$neg, filters$pos)
+    if (any(!iss %in% gbifissues$code)) {
+      stop("One or more invalid issues.")
+    }
+    if (any(!iss %in%
+            gbifissues$code[which(gbifissues$type == type)])) {
+      stop(paste("Impossible to filter",
+                 paste0(type, "s"), "by",
+                 types[which(type == types) %% 2 + 1],
+                 "related issues."))
+    }
+  }
+}
+
+parse_input <- function(...) {
+  x <- as.character(dots(...))
+  neg <- gsub('-', '', x[grepl("-", x)])
+  pos <- x[!grepl("-", x)]
+  list(neg = neg, pos = pos)
+}
+
+dots <- function(...){
+  eval(substitute(alist(...)))
+}
+
+parse_issues <- function(x){
+  sapply(x, function(y) list(issue = y), USE.NAMES = FALSE)
+}
+
+handle_issues <- function(.data, is_occ, ..., mutate = NULL) {
+  if ("data" %in% names(.data)) {
+    tmp <- .data$data
+  } else {
+    many <- FALSE
+    if (attr(.data, "type") == "many") {
+      many <- TRUE
+      tmp <- data.table::setDF(
+        data.table::rbindlist(lapply(.data, "[[", "data"),
+                              fill = TRUE, use.names = TRUE, idcol = "ind"))
+    } else {
+      tmp <- .data
+    }
+  }
+
+  # handle downloads data
+  is_dload <- FALSE
+  if (
+    all(c("issue", "accessRights", "accrualMethod") %in% names(tmp)) &&
+    !"issues" %in% names(tmp)
+  ) {
+    is_dload <- TRUE
+
+    # convert long issue names to short ones
+    issstr <- tmp[names(tmp) %in% "issue"][[1]]
+    tmp$issues <- unlist(lapply(issstr, function(z) {
+      if (identical(z, "")) return (character(1))
+      paste(gbifissues[ grepl(gsub(";", "|", z), gbifissues$issue), "code" ],
+            collapse = ",")
+    }))
+  }
+
+  if (!length(dots(...)) == 0) {
+    filters <- parse_input(...)
+    if (length(filters$neg) > 0) {
+      tmp <- tmp[ !grepl(paste(filters$neg, collapse = "|"), tmp$issues), ]
+    }
+    if (length(filters$pos) > 0) {
+      tmp <- tmp[ grepl(paste(filters$pos, collapse = "|"), tmp$issues), ]
+    }
+  }
+
+  if (!is.null(mutate)) {
+    if (mutate == 'split') {
+      tmp <- split_iss(tmp, is_occ, is_dload)
+    } else if (mutate == 'split_expand') {
+      tmp <- mutate_iss(tmp)
+      tmp <- split_iss(tmp, is_occ, is_dload)
+    } else if (mutate == 'expand') {
+      tmp <- mutate_iss(tmp)
+    }
+  }
+
+  tmp <- tibble::as_tibble(tmp)
+
+  if ("data" %in% names(.data)) {
+    .data$data <- tmp
+    return( .data )
+  } else {
+    # add same class of input data: "gbif" or "gbif_data"
+    class(tmp) <- class(.data)
+    return( tmp )
+  }
+}
+
+mutate_iss <- function(w) {
+  w$issues <- sapply(strsplit(w$issues, split = ","), function(z) {
+    paste(gbifissues[ gbifissues$code %in% z, "issue" ], collapse = ",")
+  })
+  return( w )
+}
+
+split_iss <- function(m, is_occ, is_dload) {
+  unq <- unique(unlist(strsplit(m$issues, split = ",")))
+  df <- data.table::setDF(
+    data.table::rbindlist(
+      lapply(strsplit(m$issues, split = ","), function(b) {
+        v <- unq %in% b
+        data.frame(rbind(ifelse(v, "y", "n")), stringsAsFactors = FALSE)
+      })
+    )
+  )
+  names(df) <- unq
+  m$issues <- NULL
+  if (is_occ) {
+    first_search <- c('name','key','decimalLatitude','decimalLongitude')
+    first_dload <- c('scientificName', 'taxonKey',
+                     'decimalLatitude', 'decimalLongitude')
+  } else{
+    first_search <- c('scientificName', 'key', 'nubKey',
+                      'rank', 'taxonomicStatus')
+  }
+  first <- if (is_dload) first_dload else first_search
+  tibble::as_tibble(data.frame(m[, first], df, m[, !names(m) %in% first],
+                                   stringsAsFactors = FALSE))
+}
+
 setdfrbind <- function(x) {
   (data.table::setDF(
     data.table::rbindlist(x, use.names = TRUE, fill = TRUE)))
