@@ -10,24 +10,29 @@ test_that("name_usage return parameter works", {
   # meta
   expect_is(meta, "data.frame")
   expect_is(meta, "tbl_df")
+  expect_is(meta, "tbl")
   expect_named(meta, c('offset', 'limit', 'endOfRecords'))
   expect_equal(meta$limit, 100)
 
   # data
   expect_is(dat, "data.frame")
   expect_is(dat, "tbl_df")
+  expect_is(dat, "tbl")
+  expect_is(dat, "gbif")
   expect_true(any(grepl("datasetKey", names(dat))))
   expect_equal(NROW(dat), 100)
 
   # both meta and data
-  expect_is(all, "list")
+  expect_is(all, "gbif")
   expect_named(all, c('meta', 'data'))
   expect_is(all$meta, "data.frame")
   expect_is(all$meta, "tbl_df")
+  expect_is(all$meta, "tbl")
   expect_named(all$meta, c('offset', 'limit', 'endOfRecords'))
   expect_equal(all$meta$limit, 100)
   expect_is(all$data, "data.frame")
   expect_is(all$data, "tbl_df")
+  expect_is(all$data, "tbl")
   expect_true(any(grepl("datasetKey", names(all$data))))
   expect_equal(NROW(all$data), 100)
 })
@@ -38,11 +43,11 @@ test_that("name_usage works", {
     uu <- name_usage(key = 5231190, data = 'references')
   }, preserve_exact_body_bytes = TRUE)
 
-  expect_is(tt, "list")
+  expect_is(tt, "gbif")
   expect_is(tt$data$key, "integer")
   expect_is(tt$data$kingdom, "character")
 
-  expect_is(uu, "list")
+  expect_is(uu, "gbif")
   expect_is(uu$data, "data.frame")
   expect_is(uu$data$sourceTaxonKey, "integer")
   expect_is(uu$data$citation, "character")
@@ -76,9 +81,8 @@ test_that("name_usage name route works", {
     rte1 <- name_usage(key = 5231190, data = 'name')
     rte1a <- name_usage(key = 5127291, data = 'name')
   })
-  
-  expect_is(rte1, "list")
-  expect_is(rte1a, "list")
+  expect_is(rte1, "gbif")
+  expect_is(rte1a, "gbif")
   expect_true(NROW(rte1$meta) == 0)
   expect_true(NROW(rte1a$meta) == 0)
   expect_is(rte1$data, "data.frame")
@@ -91,8 +95,8 @@ test_that("name_usage parents route works", {
     rte2a <- name_usage(key = 5135783, data = 'parents')
   }, preserve_exact_body_bytes = TRUE)
 
-  expect_is(rte2, "list")
-  expect_is(rte2a, "list")
+  expect_is(rte2, "gbif")
+  expect_is(rte2a, "gbif")
   expect_true(NROW(rte2$meta) == 0)
   expect_true(NROW(rte2a$meta) == 0)
   expect_is(rte2$data, "data.frame")
@@ -105,8 +109,8 @@ test_that("name_usage children route works", {
     rte3a <- name_usage(key = 5135790, data = 'children')
   }, preserve_exact_body_bytes = TRUE)
 
-  expect_is(rte3, "list")
-  expect_is(rte3a, "list")
+  expect_is(rte3, "gbif")
+  expect_is(rte3a, "gbif")
   expect_is(rte3$meta, "data.frame")
   expect_is(rte3a$meta, "data.frame")
   expect_is(rte3$data, "data.frame")
@@ -118,9 +122,8 @@ test_that("name_usage related route works", {
     rte4 <- name_usage(key = 5231190, data = 'related')
     rte4a <- name_usage(key = 5135787, data = 'related')
   }, preserve_exact_body_bytes = TRUE)
-  
-  expect_is(rte4, "list")
-  expect_is(rte4a, "list")
+  expect_is(rte4, "gbif")
+  expect_is(rte4a, "gbif")
   expect_is(rte4$meta, "data.frame")
   expect_is(rte4a$meta, "data.frame")
   expect_is(rte4$data, "data.frame")
@@ -132,9 +135,8 @@ test_that("name_usage synonyms route works", {
     rte5 <- name_usage(key = 5231190, data = 'synonyms')
     rte5a <- name_usage(key = 5135790, data = 'synonyms')
   })
-  
-  expect_is(rte5, "list")
-  expect_is(rte5a, "list")
+  expect_is(rte5, "gbif")
+  expect_is(rte5a, "gbif")
   expect_is(rte5$meta, "data.frame")
   expect_is(rte5a$meta, "data.frame")
   expect_equal(NROW(rte5$data), 1)
@@ -147,8 +149,8 @@ test_that("name_usage descriptions route works", {
     rte6a <- name_usage(key = 5127299, data = 'descriptions')
   }, preserve_exact_body_bytes = TRUE)
 
-  expect_is(rte6, "list")
-  expect_is(rte6a, "list")
+  expect_is(rte6, "gbif")
+  expect_is(rte6a, "gbif")
   expect_is(rte6$meta, "data.frame")
   expect_is(rte6a$meta, "data.frame")
   expect_is(rte6$data, "data.frame")
@@ -160,9 +162,8 @@ test_that("name_usage distributions route works", {
     rte7 <- name_usage(key = 5231190, data = 'distributions')
     rte7a <- name_usage(key = 5231190, data = 'distributions')
   }, preserve_exact_body_bytes = TRUE)
-  
-  expect_is(rte7, "list")
-  expect_is(rte7a, "list")
+  expect_is(rte7, "gbif")
+  expect_is(rte7a, "gbif")
   expect_is(rte7$meta, "data.frame")
   expect_is(rte7a$meta, "data.frame")
   expect_is(rte7$data, "data.frame")
@@ -174,8 +175,8 @@ test_that("name_usage media route works", {
     rte8 <- name_usage(key = 5231190, data = 'media')
     rte8a <- name_usage(key = 5231190, data = 'media')
   })
-  expect_is(rte8, "list")
-  expect_is(rte8a, "list")
+  expect_is(rte8, "gbif")
+  expect_is(rte8a, "gbif")
   expect_is(rte8$meta, "data.frame")
   expect_is(rte8a$meta, "data.frame")
   expect_is(rte8$data, "data.frame")
@@ -187,8 +188,9 @@ test_that("name_usage references route works", {
     rte9 <- name_usage(key = 5231190, data = 'references')
     rte9a <- name_usage(key = 5231190, data = 'references')
   }, preserve_exact_body_bytes = TRUE)
-  expect_is(rte9, "list")
-  expect_is(rte9a, "list")
+
+  expect_is(rte9, "gbif")
+  expect_is(rte9a, "gbif")
   expect_is(rte9$meta, "data.frame")
   expect_is(rte9a$meta, "data.frame")
   expect_is(rte9$data, "data.frame")
@@ -200,8 +202,8 @@ test_that("name_usage speciesProfiles route works", {
     rte10 <- name_usage(key = 5231190, data = 'speciesProfiles')
     rte10a <- name_usage(key = 5136020, data = 'speciesProfiles')
   })
-  expect_is(rte10, "list")
-  expect_is(rte10a, "list")
+  expect_is(rte10, "gbif")
+  expect_is(rte10a, "gbif")
   expect_is(rte10$meta, "data.frame")
   expect_is(rte10a$meta, "data.frame")
   expect_is(rte10$data, "data.frame")
@@ -213,8 +215,8 @@ test_that("name_usage vernacularNames route works", {
     rte11 <- name_usage(key = 5231190, data = 'vernacularNames')
     rte11a <- name_usage(key = 5136034, data = 'vernacularNames')
   }, preserve_exact_body_bytes = TRUE)
-  expect_is(rte11, "list")
-  expect_is(rte11a, "list")
+  expect_is(rte11, "gbif")
+  expect_is(rte11a, "gbif")
   expect_is(rte11$meta, "data.frame")
   expect_is(rte11a$meta, "data.frame")
   expect_is(rte11$data, "data.frame")
@@ -225,9 +227,9 @@ test_that("name_usage typeSpecimens route works", {
   vcr::use_cassette("name_usage_data_typeSpecimens", {
     rte12 <- name_usage(key = 5231190, data = 'typeSpecimens')
     rte12a <- name_usage(key = 5097652, data = 'typeSpecimens')
-  })
-  expect_is(rte12, "list")
-  expect_is(rte12a, "list")
+    })
+  expect_is(rte12, "gbif")
+  expect_is(rte12a, "gbif")
   expect_is(rte12$meta, "data.frame")
   expect_is(rte12a$meta, "data.frame")
   expect_equal(NROW(rte12$data), 0)
@@ -241,7 +243,7 @@ test_that("name_usage fails correctly", {
     expect_error(name_usage(key = 3119195, data = 'verbatim'))
     # Select many options, doesn't work
     expect_error(name_usage(key = 3119195, data = c('media', 'synonyms')))
-  
+
     # fails with more than 1 value
     keys <- c("73605f3a-af85-4ade-bbc5-522bfb90d847",
       "d7c60346-44b6-400d-ba27-8d3fbeffc8a5")
