@@ -9,21 +9,26 @@ test_that("returns the correct class", {
     uu <- occ_search(taxonKey=key, limit=20)
     vv <- occ_search(taxonKey=key, return='meta')
   }, preserve_exact_body_bytes = TRUE)
-  
+
+  expect_is(tt, "gbif")
   expect_is(tt$meta, "list")
   expect_is(tt$meta$endOfRecords, "logical")
   expect_is(tt$data, "data.frame")
+  expect_is(tt$data, "tbl_df")
+  expect_is(tt$data, "tbl")
   expect_is(tt$data$name, "character")
+  expect_is(uu, "gbif")
   expect_is(vv, "data.frame")
+  expect_is(vv, "tbl_df")
+  expect_is(vv, "tbl")
   # meta no longer has gbif class
   expect_equal(length(class(vv)), 3)
 
   expect_equal(tt$meta$limit, 2)
-  expect_equal(tt$hierarchy[[1]]$key[1], "6")
+  expect_equal(tt$hierarchy[[1]][1,2], "6")
   expect_equal(as.character(tt$hierarchy[[1]][1,1]), "Plantae")
 
   expect_equal(as.character(uu$hierarchy[[1]][1,1]), "Plantae")
-  expect_equal(as.character(uu$data[1, "species"]), "Encelia californica")
   expect_equal(uu$meta$limit, 20)
   expect_equal(vv$limit, 200)
 
@@ -35,10 +40,12 @@ test_that("returns the correct class", {
 test_that("returns the correct dimensions", {
   vcr::use_cassette("occ_search_datasetkey", {
     out <- occ_search(datasetKey='7b5d6a48-f762-11e1-a439-00145eb45e9a',
-      return='data')
+                      return='data')
   }, preserve_exact_body_bytes = TRUE)
 
   expect_is(out, "data.frame")
+  expect_is(out, "gbif")
+  expect_is(out, "tbl_df")
   expect_is(out$name, "character")
   expect_is(out$issues, "character")
 })
@@ -69,6 +76,8 @@ test_that("returns the correct class", {
 
   expect_is(out, "data.frame")
   expect_is(out, "tbl_df")
+  expect_is(out, "tbl")
+  expect_is(out, "gbif")
   expect_type(out$key, "character")
   expect_is(out$scientificName, "character")
 
@@ -165,27 +174,28 @@ test_that("scientificName basic use works - no synonyms", {
     # Genus is a synonym - species rank input - species not found, so Genus rank given back
     hh <- suppressMessages(occ_search(scientificName = 'Pipistrellus hesperus', limit = 2))
   }, preserve_exact_body_bytes = TRUE)
-  
+
   expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
   expect_equal(bb$data$species[1], "Pulsatilla patens")
+  bb_sc_nam <- "Anemone patens subsp. multifida (Pritzel) Hult\u00e9n"
   expect_equal(bb$data$scientificName[1],
-    "Anemone patens subsp. multifida (Pritzel) Hultén")
-  
+               bb_sc_nam)
+
   expect_is(cc, "gbif")
   expect_is(cc$data, "data.frame")
   expect_equal(attr(cc, "args")$scientificName,
-    "Corynorhinus townsendii ingens")
+               "Corynorhinus townsendii ingens")
   expect_equal(cc$data$species[1], "Corynorhinus townsendii")
   expect_equal(cc$data$scientificName[1],
-    "Corynorhinus townsendii ingens Handley, 1955")
-  
+               "Corynorhinus townsendii ingens Handley, 1955")
+
   expect_is(dd, "gbif")
   expect_is(dd$data, "data.frame")
   expect_equal(NROW(dd$data), 2)
   expect_equal(attr(dd, "args")$scientificName, "Corynorhinus townsendii")
   expect_equal(dd$data$species[1], "Corynorhinus townsendii")
   expect_equal(dd$data$scientificName[1],
-    "Corynorhinus townsendii (Cooper, 1837)")
+               "Corynorhinus townsendii (Cooper, 1837)")
 
   # expect_is(ee, "gbif")
   # expect_null(ee$data)
@@ -196,16 +206,16 @@ test_that("scientificName basic use works - no synonyms", {
   expect_equal(attr(ff, "args")$scientificName, "Myotis septentrionalis")
   expect_equal(ff$data$species[1], "Myotis septentrionalis")
   expect_equal(ff$data$scientificName[1],
-    "Myotis septentrionalis (Trouessart, 1897)")
+               "Myotis septentrionalis (Trouessart, 1897)")
 
   expect_is(hh, "gbif")
   expect_is(hh$data, "data.frame")
   expect_equal(attr(hh, "args")$scientificName, "Pipistrellus hesperus")
   expect_equal(hh$data$species[1], "Parastrellus hesperus")
   expect_equal(hh$data$scientificName[1],
-    "Pipistrellus hesperus (H.Allen, 1864)")
+               "Pipistrellus hesperus (H.Allen, 1864)")
   expect_equal(hh$data$acceptedScientificName[1],
-    "Parastrellus hesperus (H.Allen, 1864)")
+               "Parastrellus hesperus (H.Allen, 1864)")
 })
 
 
@@ -243,15 +253,15 @@ test_that("geometry inputs work as expected", {
   55.43241335888528,13.26349675655365 52.53991761181831))"
   wkt <- gsub("\n", " ", wkt)
 
-  badwkt1 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 a))"
+  badwkt1 <- "POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 a))"
 
   vcr::use_cassette("occ_search_geometry", {
     # in well known text format
-    aa <- occ_search(geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))', limit=20)
-    
+    aa <- occ_search(geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))', limit=20)
+
     # with a taxon key
     key <- 3189815
-    bb <- occ_search(taxonKey=key, geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))',
+    bb <- occ_search(taxonKey=key, geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))',
                      limit=20)
 
     # using bounding box, converted to WKT internally
@@ -279,14 +289,16 @@ test_that("geometry inputs work as expected", {
       # "source type value could not be interpreted as target at 'a'"
     )
 
-    badwkt2 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 '10.1'))"
+    # badwkt2 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 '10.1'))"
+    badwkt2 <- "POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 '10.1'))"
     expect_error(
       occ_search(geometry = badwkt2),
       "Invalid simple WKT"
       # "source type value could not be interpreted as target at ''10.1''"
     )
 
-    badwkt3 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1)"
+    # badwkt3 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1)"
+    badwkt3 <- "POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1)"
     expect_error(
       occ_search(geometry = badwkt3),
       "Invalid simple WKT"
